@@ -63,6 +63,11 @@ mbs_grl <- get_mut_type(blood_grl, type = "mbs")
 #  indel_grl <- read_vcfs_as_granges(blood_vcf_fnames, blood_sample_names,
 #                                    ref_genome, type = "indel")
 
+## ----read predefined dbs, eval=FALSE----------------------------------------------------------
+#  predefined_dbs_grl <- read_vcfs_as_granges(blood_vcf_fnames, blood_sample_names,
+#                                    ref_genome, type = "dbs",
+#                                    predefined_dbs_mbs = TRUE)
+
 ## ----mutations_from_vcf-----------------------------------------------------------------------
 muts <- mutations_from_vcf(grl[[1]])
 head(muts, 12)
@@ -271,13 +276,16 @@ plot_contribution(fit_res_strict$contribution,
   mode = "absolute"
 )
 
+## ----fit_to_signatures_strict_best_subset-----------------------------------------------------
+best_subset_refit <- fit_to_signatures_strict(mut_mat, signatures[,1:5], max_delta = 0.002, method = "best_subset")
+
 ## ----Merge_signatures-------------------------------------------------------------------------
 merged_signatures <- merge_signatures(signatures, cos_sim_cutoff = 0.8)
 
 ## ----fit_to_signatures_bootstrapped, message=FALSE--------------------------------------------
 contri_boots <- fit_to_signatures_bootstrapped(mut_mat[, c(3, 7)],
   signatures,
-  n_boots = 100,
+  n_boots = 50,
   method = "strict"
 )
 
@@ -336,6 +344,10 @@ signatures_indel[1:5, 1:5]
 signatures_artifacts = get_known_signatures(incl_poss_artifacts = TRUE)
 dim(signatures_artifacts)
 
+## ----load_signatures_grch38-------------------------------------------------------------------
+signatures_GRCh38 = get_known_signatures(genome = "GRCh38")
+dim(signatures_GRCh38)
+
 ## ----load_signatures_signal-------------------------------------------------------------------
 signatures_signal = get_known_signatures(source = "SIGNAL")
 signatures_signal[1:5, 1:5]
@@ -574,8 +586,23 @@ names(regions_density) <- c("Low", "Medium", "High")
 ## ----split_muts_region_density----------------------------------------------------------------
 grl_region_dens <- split_muts_region(grl, regions_density, include_other = FALSE)
 
+## ----combine substitutions--------------------------------------------------------------------
+gr = unlist(grl)
+
+## ----determine_regional_similarity------------------------------------------------------------
+regional_sims <- determine_regional_similarity(gr,
+                              ref_genome, 
+                              chromosomes = c("chr1", "chr2", "chr3", "chr4", "chr5", "chr6"),
+                              window_size = 40,
+                              stepsize = 10,
+                              max_window_size_gen = 40000000
+)
+
+## ----plot_regional_similarity-----------------------------------------------------------------
+plot_regional_similarity(regional_sims)
+
 ## ----plot_lesion_segregation------------------------------------------------------------------
-plot_lesion_segregation(grl[[1]])
+plot_lesion_segregation(grl[1:2])
 
 ## ----calculate_lesion_segregation-------------------------------------------------------------
 lesion_segretation <- calculate_lesion_segregation(grl, sample_names)
